namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Core.Utils;
    using Eco.Core.Utils.AtomicAction;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Services;
    using Eco.Shared.Utils;
    using Gameplay.Systems.Tooltip;

    [Serialized]
    [RequiresSkill(typeof(EngineerSkill), 0)]    
    public partial class PlanetaryDefenseSkill : Skill
    {
        public override string FriendlyName { get { return "Planetary Defense"; } }
        public override string Description { get { return Localizer.Do("(Actually) Save the Planet!"); } }

        public static int[] SkillPointCost = { 1, 1, 1, 1, 1 };
        public override int RequiredPoint { get { return this.Level < this.MaxLevel ? SkillPointCost[this.Level] : 0; } }
        public override int PrevRequiredPoint { get { return this.Level - 1 >= 0 && this.Level - 1 < this.MaxLevel ? SkillPointCost[this.Level - 1] : 0; } }
        public override int MaxLevel { get { return 1; } }
    }

    [Serialized]
    public partial class PlanetaryDefenseSkillBook : SkillBook<PlanetaryDefenseSkill, PlanetaryDefenseSkillScroll>
    {
        public override string FriendlyName { get { return "Planetary Defense Skill Book"; } }
    }

    [Serialized]
    public partial class PlanetaryDefenseSkillScroll : SkillScroll<PlanetaryDefenseSkill, PlanetaryDefenseSkillBook>
    {
        public override string FriendlyName { get { return "Planetary Defense Skill Scroll"; } }
    }

    [RequiresSkill(typeof(ElectronicsSkill), 0)] 
    public partial class PlanetaryDefenseSkillBookRecipe : Recipe
    {
        public PlanetaryDefenseSkillBookRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<PlanetaryDefenseSkillBook>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<SteelItem>(typeof(ResearchEfficiencySkill), 250, ResearchEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<GoldIngotItem>(typeof(PlanetaryDefenseEngineeringEfficiencySkill), 150, PlanetaryDefenseEngineeringEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<CircuitItem>(typeof(PlanetaryDefenseEngineeringEfficiencySkill), 75, PlanetaryDefenseEngineeringEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<CopperIngotItem>(typeof(ResearchEfficiencySkill), 100, ResearchEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<GearItem>(typeof(ResearchEfficiencySkill), 100, ResearchEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<EpoxyItem>(typeof(ResearchEfficiencySkill), 75, ResearchEfficiencySkill.MultiplicativeStrategy),
            };
            this.CraftMinutes = new ConstantValue(1440);

            this.Initialize("Planetary Defense Skill Book", typeof(PlanetaryDefenseSkillBookRecipe));
            CraftingComponent.AddRecipe(typeof(ResearchTableObject), this);
        }
    }
}
